@@ -81,7 +81,12 @@ class CompressTar(CompressInterface):
 		return tarfile.is_tarfile(file)
 
 	def extract(self, file):
-		return self.__instance.extractfile(file).read()
+		res = self.__instance.extractfile(file)
+
+		if not res:
+			return None
+		
+		return res.read()
 
 	def __iter__(self):
 		return iter(self.__instance.getnames())
