@@ -245,7 +245,7 @@ def deepcopy(file_list, folder, replace = None):
             data = __replace(data, replace)
 
             fh.close()
-            writefile(dst_file, data, os.path.getmtime(file))
+            writefile(dst_file, data)
             
 
 
